@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 # vim: tabstop=8 shiftwidth=8 expandtab
-# $Id: setupmingw32.py,v 1.14 2021/09/28 21:10:11 nanard Exp $
-# the MiniUPnP Project (c) 2007-2021 Thomas Bernard
+# $Id: setupmingw32.py,v 1.16 2024/06/22 19:23:20 nanard Exp $
+# the MiniUPnP Project (c) 2007-2024 Thomas Bernard
 # https://miniupnp.tuxfamily.org/ or http://miniupnp.free.fr/
 #
 # python script to build the miniupnpc module under windows (using mingw32)
@@ -20,13 +20,21 @@ except ImportError:
 from distutils import sysconfig
 sysconfig.get_config_vars()["OPT"] = ''
 sysconfig.get_config_vars()["CFLAGS"] = ''
+
+lic = open('LICENSE').read()
+# follow the symbolic link manually if needed
+if lic.startswith('../'):
+        lic = open(lic).read()
+
 setup(name="miniupnpc",
       version=open('VERSION').read().strip(),
       author='Thomas BERNARD',
       author_email='miniupnp@free.fr',
-      license=open('LICENSE').read(),
-      url='http://miniupnp.free.fr/',
-      description='miniUPnP client',
+      license=lic,
+      url='https://miniupnp.tuxfamily.org/',
+      description='MiniUPnP IGD client',
+      long_description=open('DESCRIPTION').read().strip(),
+      long_description_content_type='text/plain',
       ext_modules=[
          Extension(name="miniupnpc", sources=["src/miniupnpcmodule.c"],
                    libraries=["ws2_32", "iphlpapi"] + compat_lib,
